# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Platform Service (4.43.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model

from ..models.additional_data_entitlement import AdditionalDataEntitlement


class EventAdditionalData(Model):
    """Event additional data (EventAdditionalData)

    Properties:
        entitlement: (entitlement) OPTIONAL List[AdditionalDataEntitlement]

        purpose: (purpose) OPTIONAL str
    """

    # region fields

    entitlement: List[AdditionalDataEntitlement]  # OPTIONAL
    purpose: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_entitlement(
        self, value: List[AdditionalDataEntitlement]
    ) -> EventAdditionalData:
        self.entitlement = value
        return self

    def with_purpose(self, value: str) -> EventAdditionalData:
        self.purpose = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "entitlement"):
            result["entitlement"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.entitlement
            ]
        elif include_empty:
            result["entitlement"] = []
        if hasattr(self, "purpose"):
            result["purpose"] = str(self.purpose)
        elif include_empty:
            result["purpose"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        entitlement: Optional[List[AdditionalDataEntitlement]] = None,
        purpose: Optional[str] = None,
        **kwargs,
    ) -> EventAdditionalData:
        instance = cls()
        if entitlement is not None:
            instance.entitlement = entitlement
        if purpose is not None:
            instance.purpose = purpose
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> EventAdditionalData:
        instance = cls()
        if not dict_:
            return instance
        if "entitlement" in dict_ and dict_["entitlement"] is not None:
            instance.entitlement = [
                AdditionalDataEntitlement.create_from_dict(
                    i0, include_empty=include_empty
                )
                for i0 in dict_["entitlement"]
            ]
        elif include_empty:
            instance.entitlement = []
        if "purpose" in dict_ and dict_["purpose"] is not None:
            instance.purpose = str(dict_["purpose"])
        elif include_empty:
            instance.purpose = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, EventAdditionalData]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[EventAdditionalData]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        EventAdditionalData, List[EventAdditionalData], Dict[Any, EventAdditionalData]
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "entitlement": "entitlement",
            "purpose": "purpose",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "entitlement": False,
            "purpose": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: operation.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

# AccelByte Gaming Services Platform Service (4.43.0)

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Operation
from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import HttpResponse

from ...models import AliPayConfig
from ...models import ErrorEntity
from ...models import PaymentMerchantConfigInfo


class UpdateAliPayConfig(Operation):
    """Update alipay configuration (updateAliPayConfig)

    Update alipay configuration.
    Other detail info:

      * Required permission : resource="ADMIN:PAYMENT:CONFIG", action=4 (UPDATE)
      *  Returns : updated payment merchant config

    Required Permission(s):
        - ADMIN:PAYMENT:CONFIG [UPDATE]

    Properties:
        url: /platform/admin/payment/config/merchant/{id}/alipayconfig

        method: PUT

        tags: ["PaymentConfig"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH] or [BEARER_AUTH]

        body: (body) OPTIONAL AliPayConfig in body

        id_: (id) REQUIRED str in path

        sandbox: (sandbox) OPTIONAL bool in query

        validate: (validate) OPTIONAL bool in query

    Responses:
        200: OK - PaymentMerchantConfigInfo (successful operation)

        404: Not Found - ErrorEntity (33242: Payment merchant config [{id}] does not exist | 33221: Update [{paymentProvider}] config in payment merchant config [{id}] failed with message [{errMsg}])
    """

    # region fields

    _url: str = "/platform/admin/payment/config/merchant/{id}/alipayconfig"
    _method: str = "PUT"
    _consumes: List[str] = ["application/json"]
    _produces: List[str] = ["application/json"]
    _securities: List[List[str]] = [["BEARER_AUTH"], ["BEARER_AUTH"]]
    _location_query: str = None

    body: AliPayConfig  # OPTIONAL in [body]
    id_: str  # REQUIRED in [path]
    sandbox: bool  # OPTIONAL in [query]
    validate: bool  # OPTIONAL in [query]

    # endregion fields

    # region properties

    @property
    def url(self) -> str:
        return self._url

    @property
    def method(self) -> str:
        return self._method

    @property
    def consumes(self) -> List[str]:
        return self._consumes

    @property
    def produces(self) -> List[str]:
        return self._produces

    @property
    def securities(self) -> List[List[str]]:
        return self._securities

    @property
    def location_query(self) -> str:
        return self._location_query

    # endregion properties

    # region get methods

    # endregion get methods

    # region get_x_params methods

    def get_all_params(self) -> dict:
        return {
            "body": self.get_body_params(),
            "path": self.get_path_params(),
            "query": self.get_query_params(),
        }

    def get_body_params(self) -> Any:
        if not hasattr(self, "body") or self.body is None:
            return None
        return self.body.to_dict()

    def get_path_params(self) -> dict:
        result = {}
        if hasattr(self, "id_"):
            result["id"] = self.id_
        return result

    def get_query_params(self) -> dict:
        result = {}
        if hasattr(self, "sandbox"):
            result["sandbox"] = self.sandbox
        if hasattr(self, "validate"):
            result["validate"] = self.validate
        return result

    # endregion get_x_params methods

    # region is/has methods

    # endregion is/has methods

    # region with_x methods

    def with_body(self, value: AliPayConfig) -> UpdateAliPayConfig:
        self.body = value
        return self

    def with_id_(self, value: str) -> UpdateAliPayConfig:
        self.id_ = value
        return self

    def with_sandbox(self, value: bool) -> UpdateAliPayConfig:
        self.sandbox = value
        return self

    def with_validate(self, value: bool) -> UpdateAliPayConfig:
        self.validate = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "body") and self.body:
            result["body"] = self.body.to_dict(include_empty=include_empty)
        elif include_empty:
            result["body"] = AliPayConfig()
        if hasattr(self, "id_") and self.id_:
            result["id"] = str(self.id_)
        elif include_empty:
            result["id"] = ""
        if hasattr(self, "sandbox") and self.sandbox:
            result["sandbox"] = bool(self.sandbox)
        elif include_empty:
            result["sandbox"] = False
        if hasattr(self, "validate") and self.validate:
            result["validate"] = bool(self.validate)
        elif include_empty:
            result["validate"] = False
        return result

    # endregion to methods

    # region response methods

    # noinspection PyMethodMayBeStatic
    def parse_response(
        self, code: int, content_type: str, content: Any
    ) -> Tuple[
        Union[None, PaymentMerchantConfigInfo], Union[None, ErrorEntity, HttpResponse]
    ]:
        """Parse the given response.

        200: OK - PaymentMerchantConfigInfo (successful operation)

        404: Not Found - ErrorEntity (33242: Payment merchant config [{id}] does not exist | 33221: Update [{paymentProvider}] config in payment merchant config [{id}] failed with message [{errMsg}])

        ---: HttpResponse (Undocumented Response)

        ---: HttpResponse (Unexpected Content-Type Error)

        ---: HttpResponse (Unhandled Error)
        """
        pre_processed_response, error = self.pre_process_response(
            code=code, content_type=content_type, content=content
        )
        if error is not None:
            return None, None if error.is_no_content() else error
        code, content_type, content = pre_processed_response

        if code == 200:
            return PaymentMerchantConfigInfo.create_from_dict(content), None
        if code == 404:
            return None, ErrorEntity.create_from_dict(content)

        return self.handle_undocumented_response(
            code=code, content_type=content_type, content=content
        )

    # endregion response methods

    # region static methods

    @classmethod
    def create(
        cls,
        id_: str,
        body: Optional[AliPayConfig] = None,
        sandbox: Optional[bool] = None,
        validate: Optional[bool] = None,
        **kwargs,
    ) -> UpdateAliPayConfig:
        instance = cls()
        instance.id_ = id_
        if body is not None:
            instance.body = body
        if sandbox is not None:
            instance.sandbox = sandbox
        if validate is not None:
            instance.validate = validate
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> UpdateAliPayConfig:
        instance = cls()
        if "body" in dict_ and dict_["body"] is not None:
            instance.body = AliPayConfig.create_from_dict(
                dict_["body"], include_empty=include_empty
            )
        elif include_empty:
            instance.body = AliPayConfig()
        if "id" in dict_ and dict_["id"] is not None:
            instance.id_ = str(dict_["id"])
        elif include_empty:
            instance.id_ = ""
        if "sandbox" in dict_ and dict_["sandbox"] is not None:
            instance.sandbox = bool(dict_["sandbox"])
        elif include_empty:
            instance.sandbox = False
        if "validate" in dict_ and dict_["validate"] is not None:
            instance.validate = bool(dict_["validate"])
        elif include_empty:
            instance.validate = False
        return instance

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "body": "body",
            "id": "id_",
            "sandbox": "sandbox",
            "validate": "validate",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "body": False,
            "id": True,
            "sandbox": False,
            "validate": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Platform Service (4.43.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model

from ..models.credit_request import CreditRequest


class CreditResult(Model):
    """Credit result (CreditResult)

    Properties:
        credit_request: (creditRequest) OPTIONAL CreditRequest

        currency_code: (currencyCode) OPTIONAL str

        reason: (reason) OPTIONAL str

        user_id: (userId) OPTIONAL str
    """

    # region fields

    credit_request: CreditRequest  # OPTIONAL
    currency_code: str  # OPTIONAL
    reason: str  # OPTIONAL
    user_id: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_credit_request(self, value: CreditRequest) -> CreditResult:
        self.credit_request = value
        return self

    def with_currency_code(self, value: str) -> CreditResult:
        self.currency_code = value
        return self

    def with_reason(self, value: str) -> CreditResult:
        self.reason = value
        return self

    def with_user_id(self, value: str) -> CreditResult:
        self.user_id = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "credit_request"):
            result["creditRequest"] = self.credit_request.to_dict(
                include_empty=include_empty
            )
        elif include_empty:
            result["creditRequest"] = CreditRequest()
        if hasattr(self, "currency_code"):
            result["currencyCode"] = str(self.currency_code)
        elif include_empty:
            result["currencyCode"] = ""
        if hasattr(self, "reason"):
            result["reason"] = str(self.reason)
        elif include_empty:
            result["reason"] = ""
        if hasattr(self, "user_id"):
            result["userId"] = str(self.user_id)
        elif include_empty:
            result["userId"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        credit_request: Optional[CreditRequest] = None,
        currency_code: Optional[str] = None,
        reason: Optional[str] = None,
        user_id: Optional[str] = None,
        **kwargs,
    ) -> CreditResult:
        instance = cls()
        if credit_request is not None:
            instance.credit_request = credit_request
        if currency_code is not None:
            instance.currency_code = currency_code
        if reason is not None:
            instance.reason = reason
        if user_id is not None:
            instance.user_id = user_id
        return instance

    @classmethod
    def create_from_dict(cls, dict_: dict, include_empty: bool = False) -> CreditResult:
        instance = cls()
        if not dict_:
            return instance
        if "creditRequest" in dict_ and dict_["creditRequest"] is not None:
            instance.credit_request = CreditRequest.create_from_dict(
                dict_["creditRequest"], include_empty=include_empty
            )
        elif include_empty:
            instance.credit_request = CreditRequest()
        if "currencyCode" in dict_ and dict_["currencyCode"] is not None:
            instance.currency_code = str(dict_["currencyCode"])
        elif include_empty:
            instance.currency_code = ""
        if "reason" in dict_ and dict_["reason"] is not None:
            instance.reason = str(dict_["reason"])
        elif include_empty:
            instance.reason = ""
        if "userId" in dict_ and dict_["userId"] is not None:
            instance.user_id = str(dict_["userId"])
        elif include_empty:
            instance.user_id = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, CreditResult]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[CreditResult]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[CreditResult, List[CreditResult], Dict[Any, CreditResult]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "creditRequest": "credit_request",
            "currencyCode": "currency_code",
            "reason": "reason",
            "userId": "user_id",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "creditRequest": False,
            "currencyCode": False,
            "reason": False,
            "userId": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Platform Service (4.43.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class EntitlementDecrement(Model):
    """A DTO object for entitlement decrement. (EntitlementDecrement)

    Properties:
        options: (options) OPTIONAL List[str]

        request_id: (requestId) OPTIONAL str

        use_count: (useCount) OPTIONAL int
    """

    # region fields

    options: List[str]  # OPTIONAL
    request_id: str  # OPTIONAL
    use_count: int  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_options(self, value: List[str]) -> EntitlementDecrement:
        self.options = value
        return self

    def with_request_id(self, value: str) -> EntitlementDecrement:
        self.request_id = value
        return self

    def with_use_count(self, value: int) -> EntitlementDecrement:
        self.use_count = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "options"):
            result["options"] = [str(i0) for i0 in self.options]
        elif include_empty:
            result["options"] = []
        if hasattr(self, "request_id"):
            result["requestId"] = str(self.request_id)
        elif include_empty:
            result["requestId"] = ""
        if hasattr(self, "use_count"):
            result["useCount"] = int(self.use_count)
        elif include_empty:
            result["useCount"] = 0
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        options: Optional[List[str]] = None,
        request_id: Optional[str] = None,
        use_count: Optional[int] = None,
        **kwargs,
    ) -> EntitlementDecrement:
        instance = cls()
        if options is not None:
            instance.options = options
        if request_id is not None:
            instance.request_id = request_id
        if use_count is not None:
            instance.use_count = use_count
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> EntitlementDecrement:
        instance = cls()
        if not dict_:
            return instance
        if "options" in dict_ and dict_["options"] is not None:
            instance.options = [str(i0) for i0 in dict_["options"]]
        elif include_empty:
            instance.options = []
        if "requestId" in dict_ and dict_["requestId"] is not None:
            instance.request_id = str(dict_["requestId"])
        elif include_empty:
            instance.request_id = ""
        if "useCount" in dict_ and dict_["useCount"] is not None:
            instance.use_count = int(dict_["useCount"])
        elif include_empty:
            instance.use_count = 0
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, EntitlementDecrement]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[EntitlementDecrement]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        EntitlementDecrement,
        List[EntitlementDecrement],
        Dict[Any, EntitlementDecrement],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "options": "options",
            "requestId": "request_id",
            "useCount": "use_count",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "options": False,
            "requestId": False,
            "useCount": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Platform Service (4.43.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model
from accelbyte_py_sdk.core import StrEnum

from ..models.loot_box_reward import LootBoxReward


class RollFunctionEnum(StrEnum):
    CUSTOM = "CUSTOM"
    DEFAULT = "DEFAULT"


class LootBoxConfig(Model):
    """Loot box config (LootBoxConfig)

    Properties:
        reward_count: (rewardCount) OPTIONAL int

        rewards: (rewards) OPTIONAL List[LootBoxReward]

        roll_function: (rollFunction) OPTIONAL Union[str, RollFunctionEnum]
    """

    # region fields

    reward_count: int  # OPTIONAL
    rewards: List[LootBoxReward]  # OPTIONAL
    roll_function: Union[str, RollFunctionEnum]  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_reward_count(self, value: int) -> LootBoxConfig:
        self.reward_count = value
        return self

    def with_rewards(self, value: List[LootBoxReward]) -> LootBoxConfig:
        self.rewards = value
        return self

    def with_roll_function(self, value: Union[str, RollFunctionEnum]) -> LootBoxConfig:
        self.roll_function = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "reward_count"):
            result["rewardCount"] = int(self.reward_count)
        elif include_empty:
            result["rewardCount"] = 0
        if hasattr(self, "rewards"):
            result["rewards"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.rewards
            ]
        elif include_empty:
            result["rewards"] = []
        if hasattr(self, "roll_function"):
            result["rollFunction"] = str(self.roll_function)
        elif include_empty:
            result["rollFunction"] = Union[str, RollFunctionEnum]()
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        reward_count: Optional[int] = None,
        rewards: Optional[List[LootBoxReward]] = None,
        roll_function: Optional[Union[str, RollFunctionEnum]] = None,
        **kwargs,
    ) -> LootBoxConfig:
        instance = cls()
        if reward_count is not None:
            instance.reward_count = reward_count
        if rewards is not None:
            instance.rewards = rewards
        if roll_function is not None:
            instance.roll_function = roll_function
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> LootBoxConfig:
        instance = cls()
        if not dict_:
            return instance
        if "rewardCount" in dict_ and dict_["rewardCount"] is not None:
            instance.reward_count = int(dict_["rewardCount"])
        elif include_empty:
            instance.reward_count = 0
        if "rewards" in dict_ and dict_["rewards"] is not None:
            instance.rewards = [
                LootBoxReward.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["rewards"]
            ]
        elif include_empty:
            instance.rewards = []
        if "rollFunction" in dict_ and dict_["rollFunction"] is not None:
            instance.roll_function = str(dict_["rollFunction"])
        elif include_empty:
            instance.roll_function = Union[str, RollFunctionEnum]()
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, LootBoxConfig]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[LootBoxConfig]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[LootBoxConfig, List[LootBoxConfig], Dict[Any, LootBoxConfig]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "rewardCount": "reward_count",
            "rewards": "rewards",
            "rollFunction": "roll_function",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "rewardCount": False,
            "rewards": False,
            "rollFunction": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "rollFunction": ["CUSTOM", "DEFAULT"],
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Platform Service (4.43.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class RevocationError(Model):
    """Revocation error (RevocationError)

    Properties:
        code: (code) OPTIONAL int

        http_status: (httpStatus) OPTIONAL int

        message: (message) OPTIONAL str
    """

    # region fields

    code: int  # OPTIONAL
    http_status: int  # OPTIONAL
    message: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_code(self, value: int) -> RevocationError:
        self.code = value
        return self

    def with_http_status(self, value: int) -> RevocationError:
        self.http_status = value
        return self

    def with_message(self, value: str) -> RevocationError:
        self.message = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "code"):
            result["code"] = int(self.code)
        elif include_empty:
            result["code"] = 0
        if hasattr(self, "http_status"):
            result["httpStatus"] = int(self.http_status)
        elif include_empty:
            result["httpStatus"] = 0
        if hasattr(self, "message"):
            result["message"] = str(self.message)
        elif include_empty:
            result["message"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        code: Optional[int] = None,
        http_status: Optional[int] = None,
        message: Optional[str] = None,
        **kwargs,
    ) -> RevocationError:
        instance = cls()
        if code is not None:
            instance.code = code
        if http_status is not None:
            instance.http_status = http_status
        if message is not None:
            instance.message = message
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> RevocationError:
        instance = cls()
        if not dict_:
            return instance
        if "code" in dict_ and dict_["code"] is not None:
            instance.code = int(dict_["code"])
        elif include_empty:
            instance.code = 0
        if "httpStatus" in dict_ and dict_["httpStatus"] is not None:
            instance.http_status = int(dict_["httpStatus"])
        elif include_empty:
            instance.http_status = 0
        if "message" in dict_ and dict_["message"] is not None:
            instance.message = str(dict_["message"])
        elif include_empty:
            instance.message = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, RevocationError]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[RevocationError]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[RevocationError, List[RevocationError], Dict[Any, RevocationError]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "code": "code",
            "httpStatus": "http_status",
            "message": "message",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "code": False,
            "httpStatus": False,
            "message": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Platform Service (4.43.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class TwitchIAPConfigRequest(Model):
    """Twitch IAP config request (TwitchIAPConfigRequest)

    Properties:
        client_id: (clientId) OPTIONAL str

        client_secret: (clientSecret) OPTIONAL str

        organization_id: (organizationId) OPTIONAL str
    """

    # region fields

    client_id: str  # OPTIONAL
    client_secret: str  # OPTIONAL
    organization_id: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_client_id(self, value: str) -> TwitchIAPConfigRequest:
        self.client_id = value
        return self

    def with_client_secret(self, value: str) -> TwitchIAPConfigRequest:
        self.client_secret = value
        return self

    def with_organization_id(self, value: str) -> TwitchIAPConfigRequest:
        self.organization_id = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "client_id"):
            result["clientId"] = str(self.client_id)
        elif include_empty:
            result["clientId"] = ""
        if hasattr(self, "client_secret"):
            result["clientSecret"] = str(self.client_secret)
        elif include_empty:
            result["clientSecret"] = ""
        if hasattr(self, "organization_id"):
            result["organizationId"] = str(self.organization_id)
        elif include_empty:
            result["organizationId"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        client_id: Optional[str] = None,
        client_secret: Optional[str] = None,
        organization_id: Optional[str] = None,
        **kwargs,
    ) -> TwitchIAPConfigRequest:
        instance = cls()
        if client_id is not None:
            instance.client_id = client_id
        if client_secret is not None:
            instance.client_secret = client_secret
        if organization_id is not None:
            instance.organization_id = organization_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> TwitchIAPConfigRequest:
        instance = cls()
        if not dict_:
            return instance
        if "clientId" in dict_ and dict_["clientId"] is not None:
            instance.client_id = str(dict_["clientId"])
        elif include_empty:
            instance.client_id = ""
        if "clientSecret" in dict_ and dict_["clientSecret"] is not None:
            instance.client_secret = str(dict_["clientSecret"])
        elif include_empty:
            instance.client_secret = ""
        if "organizationId" in dict_ and dict_["organizationId"] is not None:
            instance.organization_id = str(dict_["organizationId"])
        elif include_empty:
            instance.organization_id = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, TwitchIAPConfigRequest]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[TwitchIAPConfigRequest]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        TwitchIAPConfigRequest,
        List[TwitchIAPConfigRequest],
        Dict[Any, TwitchIAPConfigRequest],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "clientId": "client_id",
            "clientSecret": "client_secret",
            "organizationId": "organization_id",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "clientId": False,
            "clientSecret": False,
            "organizationId": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: wrapper.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import get_namespace as get_services_namespace
from accelbyte_py_sdk.core import run_request
from accelbyte_py_sdk.core import run_request_async
from accelbyte_py_sdk.core import same_doc_as

from ..models import ValidationErrorEntity
from ..models import XblUserSessionRequest

from ..operations.session_platform import RegisterXblSessions


@same_doc_as(RegisterXblSessions)
def register_xbl_sessions(
    user_id: str,
    body: Optional[XblUserSessionRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Register/Update a session (registerXblSessions)

    This API is used to register/update a session on xbox.

    Other detail info:

      * Required permission : resource=ADMIN:NAMESPACE:{namespace}:USER:{userId}:INTEGRATION, action=4 (UPDATE)

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/session/xbl

        method: PUT

        tags: ["Session(Platform)"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL XblUserSessionRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - Dict[str, Any] (OK)

        400: Bad Request - ValidationErrorEntity (20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = RegisterXblSessions.create(
        user_id=user_id,
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(RegisterXblSessions)
async def register_xbl_sessions_async(
    user_id: str,
    body: Optional[XblUserSessionRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Register/Update a session (registerXblSessions)

    This API is used to register/update a session on xbox.

    Other detail info:

      * Required permission : resource=ADMIN:NAMESPACE:{namespace}:USER:{userId}:INTEGRATION, action=4 (UPDATE)

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/session/xbl

        method: PUT

        tags: ["Session(Platform)"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL XblUserSessionRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - Dict[str, Any] (OK)

        400: Bad Request - ValidationErrorEntity (20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = RegisterXblSessions.create(
        user_id=user_id,
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Platform Service (4.43.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model

from ..models.consumable_entitlement_revocation_config import (
    ConsumableEntitlementRevocationConfig,
)
from ..models.durable_entitlement_revocation_config import (
    DurableEntitlementRevocationConfig,
)


class EntitlementRevocationConfig(Model):
    """Entitlement revocation config (EntitlementRevocationConfig)

    Properties:
        consumable: (consumable) OPTIONAL ConsumableEntitlementRevocationConfig

        durable: (durable) OPTIONAL DurableEntitlementRevocationConfig
    """

    # region fields

    consumable: ConsumableEntitlementRevocationConfig  # OPTIONAL
    durable: DurableEntitlementRevocationConfig  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_consumable(
        self, value: ConsumableEntitlementRevocationConfig
    ) -> EntitlementRevocationConfig:
        self.consumable = value
        return self

    def with_durable(
        self, value: DurableEntitlementRevocationConfig
    ) -> EntitlementRevocationConfig:
        self.durable = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "consumable"):
            result["consumable"] = self.consumable.to_dict(include_empty=include_empty)
        elif include_empty:
            result["consumable"] = ConsumableEntitlementRevocationConfig()
        if hasattr(self, "durable"):
            result["durable"] = self.durable.to_dict(include_empty=include_empty)
        elif include_empty:
            result["durable"] = DurableEntitlementRevocationConfig()
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        consumable: Optional[ConsumableEntitlementRevocationConfig] = None,
        durable: Optional[DurableEntitlementRevocationConfig] = None,
        **kwargs,
    ) -> EntitlementRevocationConfig:
        instance = cls()
        if consumable is not None:
            instance.consumable = consumable
        if durable is not None:
            instance.durable = durable
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> EntitlementRevocationConfig:
        instance = cls()
        if not dict_:
            return instance
        if "consumable" in dict_ and dict_["consumable"] is not None:
            instance.consumable = (
                ConsumableEntitlementRevocationConfig.create_from_dict(
                    dict_["consumable"], include_empty=include_empty
                )
            )
        elif include_empty:
            instance.consumable = ConsumableEntitlementRevocationConfig()
        if "durable" in dict_ and dict_["durable"] is not None:
            instance.durable = DurableEntitlementRevocationConfig.create_from_dict(
                dict_["durable"], include_empty=include_empty
            )
        elif include_empty:
            instance.durable = DurableEntitlementRevocationConfig()
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, EntitlementRevocationConfig]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[EntitlementRevocationConfig]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        EntitlementRevocationConfig,
        List[EntitlementRevocationConfig],
        Dict[Any, EntitlementRevocationConfig],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "consumable": "consumable",
            "durable": "durable",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "consumable": False,
            "durable": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Platform Service (4.43.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class TLSConfig(Model):
    """TLS config (TLSConfig)

    Properties:
        root_cert_file_bytes: (rootCertFileBytes) OPTIONAL List[str]

        root_cert_file_name: (rootCertFileName) OPTIONAL str
    """

    # region fields

    root_cert_file_bytes: List[str]  # OPTIONAL
    root_cert_file_name: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_root_cert_file_bytes(self, value: List[str]) -> TLSConfig:
        self.root_cert_file_bytes = value
        return self

    def with_root_cert_file_name(self, value: str) -> TLSConfig:
        self.root_cert_file_name = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "root_cert_file_bytes"):
            result["rootCertFileBytes"] = [str(i0) for i0 in self.root_cert_file_bytes]
        elif include_empty:
            result["rootCertFileBytes"] = []
        if hasattr(self, "root_cert_file_name"):
            result["rootCertFileName"] = str(self.root_cert_file_name)
        elif include_empty:
            result["rootCertFileName"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        root_cert_file_bytes: Optional[List[str]] = None,
        root_cert_file_name: Optional[str] = None,
        **kwargs,
    ) -> TLSConfig:
        instance = cls()
        if root_cert_file_bytes is not None:
            instance.root_cert_file_bytes = root_cert_file_bytes
        if root_cert_file_name is not None:
            instance.root_cert_file_name = root_cert_file_name
        return instance

    @classmethod
    def create_from_dict(cls, dict_: dict, include_empty: bool = False) -> TLSConfig:
        instance = cls()
        if not dict_:
            return instance
        if "rootCertFileBytes" in dict_ and dict_["rootCertFileBytes"] is not None:
            instance.root_cert_file_bytes = [
                str(i0) for i0 in dict_["rootCertFileBytes"]
            ]
        elif include_empty:
            instance.root_cert_file_bytes = []
        if "rootCertFileName" in dict_ and dict_["rootCertFileName"] is not None:
            instance.root_cert_file_name = str(dict_["rootCertFileName"])
        elif include_empty:
            instance.root_cert_file_name = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, TLSConfig]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[TLSConfig]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[TLSConfig, List[TLSConfig], Dict[Any, TLSConfig]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "rootCertFileBytes": "root_cert_file_bytes",
            "rootCertFileName": "root_cert_file_name",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "rootCertFileBytes": False,
            "rootCertFileName": False,
        }

    # endregion static methods
